# Supported Platforms

###### Regularly tested

- Arista vEOS
- Cisco ASA
- Cisco IOS
- Cisco IOS-XE
- Cisco IOS-XR
- Cisco NX-OS
- Cisco SG300
- HP ProCurve
- Juniper Junos
- Linux

###### Limited testing

- Alcatel AOS6/AOS8
- Apresia Systems AEOS
- Calix B6
- Cisco AireOS (Wireless LAN Controllers)
- CloudGenix ION
- Dell OS9 (Force10)
- Dell OS10
- Dell PowerConnect
- Extreme ERS (Avaya)
- Extreme VSP (Avaya)
- Extreme VDX (Brocade)
- Extreme MLX/NetIron (Brocade/Foundry)
- HPE Comware7
- Huawei
- IP Infusion OcNOS
- Juniper ScreenOS
- Mellanox
- MikroTik RouterOS
- MikroTik SwitchOS
- NetApp cDOT
- Nokia/Alcatel SR OS
- OneAccess
- Palo Alto PAN-OS
- Pluribus
- Ruckus ICX/FastIron
- Ruijie Networks
- Ubiquiti EdgeSwitch
- Vyatta VyOS

###### Experimental

- A10
- Accedian
- Aruba
- Ciena SAOS
- Citrix Netscaler
- Cisco Telepresence
- Check Point GAiA
- Coriant
- Dell OS6
- Dell EMC Isilon
- Eltex
- Enterasys
- Endace
- Extreme EXOS
- Extreme Wing
- Extreme SLX (Brocade)
- F5 TMSH
- F5 Linux
- Fortinet
- MRV Communications OptiSwitch
- MRV LX
- Nokia/Alcatel SR-OS
- QuantaMesh
- Rad ETX
- Sophos SFOS
- Versa Networks FlexVNF
- Watchguard Firebox
